@@ -1,3 +1,5 @@
 from .integration.pons2000 import *
 from .integration.rezzolla2003 import *
 from .unit.wavefan_test import *
+from .unit.rarefaction_test import *
+from .unit.solver_test import *
